@@ -22,26 +22,26 @@ function PMA_RTE_getFooterLinks($docu, $priv, $name)
 {
     global $db, $table, $url_query, $ajax_class;
 
-    $icon = /*overload*/mb_strtolower($name) . '_add.png';
+    $icon = mb_strtolower($name) . '_add.png';
     $retval  = "";
     $retval .= "<!-- ADD " . $name . " FORM START -->\n";
     $retval .= "<fieldset class='left'>\n";
     $retval .= "<legend>" . _pgettext('Create new procedure', 'New') . "</legend>\n";
     $retval .= "        <div class='wrap'>\n";
-    if (PMA_Util::currentUserHasPrivilege($priv, $db, $table)) {
+    if (PMA\libraries\Util::currentUserHasPrivilege($priv, $db, $table)) {
         $retval .= "            <a {$ajax_class['add']} ";
-        $retval .= "href='db_" . /*overload*/mb_strtolower($name) . "s.php";
+        $retval .= "href='db_" . mb_strtolower($name) . "s.php";
         $retval .= "$url_query&amp;add_item=1' ";
         $retval .= "onclick='$.datepicker.initialized = false;'>";
         $icon = 'b_' . $icon;
-        $retval .= PMA_Util::getIcon($icon);
+        $retval .= PMA\libraries\Util::getIcon($icon);
         $retval .= PMA_RTE_getWord('add') . "</a>\n";
     } else {
         $icon = 'bd_' . $icon;
-        $retval .= PMA_Util::getIcon($icon);
+        $retval .= PMA\libraries\Util::getIcon($icon);
         $retval .= PMA_RTE_getWord('add') . "\n";
     }
-    $retval .= "            " . PMA_Util::showMySQLDocu($docu) . "\n";
+    $retval .= "            " . PMA\libraries\Util::showMySQLDocu($docu) . "\n";
     $retval .= "        </div>\n";
     $retval .= "</fieldset>\n";
     $retval .= "<!-- ADD " . $name . " FORM END -->\n\n";
@@ -88,7 +88,7 @@ function PMA_EVN_getFooterLinks()
         0,
         1
     );
-    $es_state = /*overload*/mb_strtolower($es_state);
+    $es_state = mb_strtolower($es_state);
     $options = array(
                     0 => array(
                         'label' => __('OFF'),
@@ -112,7 +112,7 @@ function PMA_EVN_getFooterLinks()
     $retval .= "        </legend>\n";
     $retval .= "        <div class='wrap'>\n";
     // show the toggle button
-    $retval .= PMA_Util::toggleButton(
+    $retval .= PMA\libraries\Util::toggleButton(
         "sql.php$url_query&amp;goto=db_events.php" . urlencode("?db=$db"),
         'sql_query',
         $options,
@@ -127,4 +127,3 @@ function PMA_EVN_getFooterLinks()
     return $retval;
 } // end PMA_EVN_getFooterLinks()
 
-?>
